pub struct NapiClient { /* private fields */ }Expand description
A WebTransport client that can connect to servers.
Implementations
Sourceimpl NapiClient
impl NapiClient
Sourcepub fn with_system_roots() -> Result<Self>
pub fn with_system_roots() -> Result<Self>
Create a client that validates server certificates against system root CAs.
Sourcepub fn disable_verify() -> Result<Self>
pub fn disable_verify() -> Result<Self>
Create a client that skips certificate verification entirely. WARNING: Only use for testing with self-signed certificates.
Sourcepub fn with_certificate_hashes(hashes: Vec<Buffer>) -> Result<Self>
pub fn with_certificate_hashes(hashes: Vec<Buffer>) -> Result<Self>
Create a client that validates server certificates by SHA-256 hash.
Sourcepub async fn connect(&self, url_str: String) -> Result<NapiSession>
pub async fn connect(&self, url_str: String) -> Result<NapiSession>
Connect to a WebTransport server at the given URL.